//  
//   Rebex Sample Code License
// 
//   Copyright 2024, REBEX CR s.r.o.
//   All rights reserved.
//   https://www.rebex.net/
// 
//   Permission to use, copy, modify, and/or distribute this software for any
//   purpose with or without fee is hereby granted.
// 
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//   OTHER DEALINGS IN THE SOFTWARE.
// 

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Rebex.IO.Compression;

namespace Rebex.Samples
{
    /// <summary>
    /// A dialog that displays a progress of the current operation.
    /// </summary>
    public partial class ProgressDialog : Form
    {
        // ZIP archive
        private readonly ZipArchive _archive;

        /// <summary>
        /// Initializes a new instance of the dialog.
        /// </summary>
        /// <param name="archive">Archive performing the operation.</param>
        /// <param name="title">Dialog title.</param>
        public ProgressDialog(ZipArchive archive, string title)
        {
            InitializeComponent();

            this.Text = title;

            lblFileIndex.Text = "";
            lblFileArchivePath.Text = "";
            lblFileExternalPath.Text = "";

            _archive = archive;
        }

        /// <summary>
        /// Adjusts the dialog controls according to the specified event arguments.
        /// </summary>
        /// <param name="e"></param>
        public void ProgressChanged(ZipProgressChangedEventArgs e)
        {
            if (e.OperationStep == ArchiveOperationStep.HierarchyRetrieving)
            {
                lblFileIndex.Text = "Retrieving hierarchy...";
            }
            else
            {
                if (progressBarOverall.Value != e.ProgressPercentage)
                    progressBarOverall.Value = e.ProgressPercentage;

                if (progressBarCurrentFile.Value != e.CurrentFileProgressPercentage)
                    progressBarCurrentFile.Value = e.CurrentFileProgressPercentage;

                if (e.OperationStep == ArchiveOperationStep.FileChecking || e.OperationStep == ArchiveOperationStep.FileProcessing)
                {
                    lblFileIndex.Text = string.Format("{0}. / {1}", e.FilesProcessed + 1, e.FilesTotal);
                    lblFileArchivePath.Text = e.ArchiveItemPath;
                    lblFileExternalPath.Text = e.ExternalItemPath;
                }
            }
        }

        /// <summary>
        /// Handles a Cancel click.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCancel_Click(object sender, EventArgs e)
        {
            _archive.Cancel();
        }

        /// <summary>
        /// Hanldes a FormClosing event.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ProgressDialog_FormClosing(object sender, FormClosingEventArgs e)
        {
            _archive.Cancel();
        }
    }
}